@@ -40,7 +40,7 @@ private:
 private:
   std::list<Level>      levels;
   Lum::Model::ActionRef commitAction;
-  Lum::Model::SizeTRef  level;
+  Lum::Model::ULongRef  level;
   bool                  success;
 
 public:
